#!/usr/bin/env bash
set -Eeuo pipefail
trap 'echo "ERROR: $BASH_SOURCE:$LINENO $BASH_COMMAND" >&2' ERR

readonly -a users=(
	'hades-agent'
	'hades-auth-dhcp'
	'hades-auth-dns'
	'hades-database'
	'hades-portal'
	'hades-radius'
	'hades-unauth'
)
readonly -A groups=(
	['hades-agent']='hades-agent'
	['hades-auth-dhcp']='hades-auth-dhcp'
	['hades-auth-dns']='hades-auth-dns'
	['hades-database']='hades-database'
	['hades-portal']='hades-portal'
	['hades-radius']='hades-radius'
	['hades-unauth']='hades-unauth'
)
readonly -A homes=(
	['hades-agent']='/var/lib/hades/agent'
	['hades-auth-dhcp']='/var/lib/hades/auth-dhcp'
	['hades-auth-dns']='/var/lib/hades/auth-dns'
	['hades-database']='/var/lib/hades/database'
	['hades-portal']='/var/lib/hades/portal'
	['hades-radius']='/var/lib/hades/radius'
	['hades-unauth']='/var/lib/hades/unauth-dns'
)
readonly -A services=(
	['agent']='hades-agent'
	['auth-dhcp']='hades-auth-dhcp'
	['auth-dns']='hades-auth-dns'
	['auth-vrrp']=
	['database']='hades-database'
	['radius']='hades-radius'
	['radius-vrrp']=
	['unauth-dns']='hades-unauth'
	['unauth-http']='hades-portal'
	['unauth-portal']='hades-portal'
	['unauth-vrrp']=
)

if ! getent group 'hades' &>/dev/null; then
	echo "Creating hades group ..."
	addgroup --quiet --system 'hades'
	chgrp -R 'hades' '/etc/hades'
fi

for user in "${users[@]}"; do
	group="${groups[$user]}"
	home="${homes[$user]}"
	if ! getent group "$group" &>/dev/null; then
		echo "Creating $group group ..."
		addgroup --quiet --system "$group"
	fi
	if [[ ! -d "$home" ]]; then
		echo "Creating $home directory ..."
		mkdir -p "$home"
	fi
	if ! getent passwd "$user" &>/dev/null; then
		echo "Creating $user user ..."
		adduser --quiet --system --home "$home" --no-create-home --ingroup "$group" --disabled-password "$user"
		adduser --quiet "$user" 'hades'
		chown "$user":"$group" "$home"
		chmod o= "$home"
	fi
done

for service in "${!services[@]}"; do
	user="${services[$service]}"
	directory="/var/lib/hades/$service"
	if [[ ! -d "$directory" ]]; then
		echo "Creating $directory directory ..."
		mkdir -p "$directory"
		if [[ -n "$user" ]]; then
			group="${groups[$user]}"
			chown "$user":"$group" "$directory"
			chmod o= "$directory"
		fi
	fi
done
