--
-- PostgreSQL database dump
--

-- Dumped from database version 9.6.2
-- Dumped by pg_dump version 9.6.2

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


--
-- Name: postgres_fdw; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS postgres_fdw WITH SCHEMA public;


--
-- Name: EXTENSION postgres_fdw; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION postgres_fdw IS 'foreign-data wrapper for remote PostgreSQL servers';


SET search_path = public, pg_catalog;

--
-- Name: decode_attribute_value_pairs(text); Type: FUNCTION; Schema: public; Owner: hades-database
--

CREATE FUNCTION decode_attribute_value_pairs(string text) RETURNS text[]
    LANGUAGE plpgsql IMMUTABLE STRICT
    AS $_$
DECLARE
    rv text;
BEGIN
    SELECT array_agg(keyval) INTO STRICT rv FROM (SELECT regexp_matches(string, '(?:\A|, )([^=]+) = ((?:"(?:\\.|[^"\\])*"|(?!")[^,]*))(?:$|(?=, ))', 'g') as keyval) AS matches;
    RETURN rv;
END;
$_$;


ALTER FUNCTION public.decode_attribute_value_pairs(string text) OWNER TO "hades-database";

--
-- Name: FUNCTION decode_attribute_value_pairs(string text); Type: COMMENT; Schema: public; Owner: hades-database
--

COMMENT ON FUNCTION decode_attribute_value_pairs(string text) IS 'Decode freeRADIUS attribute-values pairs as exportet by the pairs xlat function into an array of arrays of key-value pairs.';


--
-- Name: decode_equals_encoding(text); Type: FUNCTION; Schema: public; Owner: hades-database
--

CREATE FUNCTION decode_equals_encoding(string text) RETURNS text
    LANGUAGE plpgsql IMMUTABLE STRICT
    AS $$
DECLARE
    rv text;
BEGIN
    SELECT string_agg(concat(convert_from(decode(match[1], 'hex'), 'SQL_ASCII'), match[2]), '') INTO STRICT rv FROM (
            SELECT regexp_matches(string, '(?:=([0-9a-f]{2})|([^=]+))', 'gi') as match
        ) AS tokens;
    RETURN rv;
END;
$$;


ALTER FUNCTION public.decode_equals_encoding(string text) OWNER TO "hades-database";

--
-- Name: FUNCTION decode_equals_encoding(string text); Type: COMMENT; Schema: public; Owner: hades-database
--

COMMENT ON FUNCTION decode_equals_encoding(string text) IS 'Decode a string, where some bytes have been encoded with a scheme similar to the percent encoding of URIs: an equal sign (=) followed by two hexadecimal characters';


--
-- Name: safe_inet_cast(text); Type: FUNCTION; Schema: public; Owner: hades-database
--

CREATE FUNCTION safe_inet_cast(inp text) RETURNS inet
    LANGUAGE plpgsql IMMUTABLE STRICT
    AS $$
BEGIN
    RETURN CAST(inp AS inet);
EXCEPTION WHEN data_exception THEN
    RETURN NULL;
END;
$$;


ALTER FUNCTION public.safe_inet_cast(inp text) OWNER TO "hades-database";

--
-- Name: safe_macaddr_cast(text); Type: FUNCTION; Schema: public; Owner: hades-database
--

CREATE FUNCTION safe_macaddr_cast(inp text) RETURNS macaddr
    LANGUAGE plpgsql IMMUTABLE STRICT
    AS $$
BEGIN
    RETURN CAST(inp AS macaddr);
EXCEPTION WHEN data_exception THEN
    RETURN NULL;
END;
$$;


ALTER FUNCTION public.safe_macaddr_cast(inp text) OWNER TO "hades-database";

--
-- Name: master; Type: SERVER; Schema: -; Owner: hades-database
--

CREATE SERVER master FOREIGN DATA WRAPPER postgres_fdw OPTIONS (
    dbname 'foreign',
    host '127.0.0.1'
);


ALTER SERVER master OWNER TO "hades-database";

--
-- Name: USER MAPPING public SERVER master; Type: USER MAPPING; Schema: -; Owner: hades-database
--

CREATE USER MAPPING FOR public SERVER master OPTIONS (
    password 'foreign',
    "user" 'foreign'
);


SET default_tablespace = '';

--
-- Name: foreign_alternative_dns; Type: FOREIGN TABLE; Schema: public; Owner: hades-database
--

CREATE FOREIGN TABLE foreign_alternative_dns (
    "IpAddress" inet
)
SERVER master
OPTIONS (
    table_name 'alternative_dns'
);


ALTER FOREIGN TABLE foreign_alternative_dns OWNER TO "hades-database";

--
-- Name: alternative_dns; Type: MATERIALIZED VIEW; Schema: public; Owner: hades-database
--

CREATE MATERIALIZED VIEW alternative_dns AS
 SELECT foreign_alternative_dns."IpAddress"
   FROM foreign_alternative_dns
  GROUP BY foreign_alternative_dns."IpAddress"
  WITH NO DATA;


ALTER TABLE alternative_dns OWNER TO "hades-database";

--
-- Name: foreign_dhcphost; Type: FOREIGN TABLE; Schema: public; Owner: hades-database
--

CREATE FOREIGN TABLE foreign_dhcphost (
    "Mac" macaddr,
    "IpAddress" inet
)
SERVER master
OPTIONS (
    table_name 'dhcphost'
);


ALTER FOREIGN TABLE foreign_dhcphost OWNER TO "hades-database";

--
-- Name: dhcphost; Type: MATERIALIZED VIEW; Schema: public; Owner: hades-database
--

CREATE MATERIALIZED VIEW dhcphost AS
 SELECT indexed."Mac",
    indexed."IpAddress"
   FROM ( SELECT row_number() OVER "Mac_window" AS "Mac_index",
            row_number() OVER "IpAddress_window" AS "IpAddress_index",
            foreign_dhcphost."Mac",
            foreign_dhcphost."IpAddress"
           FROM foreign_dhcphost
          WHERE ((foreign_dhcphost."Mac" IS NOT NULL) AND (foreign_dhcphost."IpAddress" IS NOT NULL))
          WINDOW "Mac_window" AS (PARTITION BY foreign_dhcphost."Mac"), "IpAddress_window" AS (PARTITION BY foreign_dhcphost."IpAddress")) indexed
  WHERE ((indexed."Mac_index" = 1) AND (indexed."IpAddress_index" = 1))
  WITH NO DATA;


ALTER TABLE dhcphost OWNER TO "hades-database";

--
-- Name: foreign_nas; Type: FOREIGN TABLE; Schema: public; Owner: hades-database
--

CREATE FOREIGN TABLE foreign_nas (
    "Id" integer,
    "NASName" text,
    "ShortName" text,
    "Type" text DEFAULT 'other'::character varying,
    "Ports" integer,
    "Secret" text,
    "Server" text,
    "Community" text,
    "Description" text
)
SERVER master
OPTIONS (
    table_name 'nas'
);


ALTER FOREIGN TABLE foreign_nas OWNER TO "hades-database";

--
-- Name: foreign_radcheck; Type: FOREIGN TABLE; Schema: public; Owner: hades-database
--

CREATE FOREIGN TABLE foreign_radcheck (
    "Priority" integer,
    "UserName" text,
    "NASIpAddress" inet,
    "NASPortId" text,
    "Attribute" text,
    "Op" character(2),
    "Value" text
)
SERVER master
OPTIONS (
    table_name 'radcheck'
);


ALTER FOREIGN TABLE foreign_radcheck OWNER TO "hades-database";

--
-- Name: foreign_radgroupcheck; Type: FOREIGN TABLE; Schema: public; Owner: hades-database
--

CREATE FOREIGN TABLE foreign_radgroupcheck (
    "Priority" integer,
    "GroupName" text,
    "Attribute" text,
    "Op" character(2),
    "Value" text
)
SERVER master
OPTIONS (
    table_name 'radgroupcheck'
);


ALTER FOREIGN TABLE foreign_radgroupcheck OWNER TO "hades-database";

--
-- Name: foreign_radgroupreply; Type: FOREIGN TABLE; Schema: public; Owner: hades-database
--

CREATE FOREIGN TABLE foreign_radgroupreply (
    "Priority" integer,
    "GroupName" text,
    "Attribute" text,
    "Op" character(2),
    "Value" text
)
SERVER master
OPTIONS (
    table_name 'radgroupreply'
);


ALTER FOREIGN TABLE foreign_radgroupreply OWNER TO "hades-database";

--
-- Name: foreign_radreply; Type: FOREIGN TABLE; Schema: public; Owner: hades-database
--

CREATE FOREIGN TABLE foreign_radreply (
    "Priority" integer,
    "UserName" text,
    "NASIpAddress" inet,
    "NASPortId" text,
    "Attribute" text,
    "Op" character(2) DEFAULT '='::bpchar,
    "Value" text
)
SERVER master
OPTIONS (
    table_name 'radreply'
);


ALTER FOREIGN TABLE foreign_radreply OWNER TO "hades-database";

--
-- Name: foreign_radusergroup; Type: FOREIGN TABLE; Schema: public; Owner: hades-database
--

CREATE FOREIGN TABLE foreign_radusergroup (
    "UserName" text,
    "NASIpAddress" inet,
    "NASPortId" text,
    "GroupName" text,
    "Priority" integer
)
SERVER master
OPTIONS (
    table_name 'radusergroup'
);


ALTER FOREIGN TABLE foreign_radusergroup OWNER TO "hades-database";

--
-- Name: nas; Type: MATERIALIZED VIEW; Schema: public; Owner: hades-database
--

CREATE MATERIALIZED VIEW nas AS
 SELECT row_number() OVER () AS "Id",
    indexed."NASName",
    indexed."ShortName",
    indexed."Type",
    indexed."Ports",
    indexed."Secret",
    indexed."Server",
    indexed."Community",
    indexed."Description"
   FROM ( SELECT row_number() OVER "NASName_window" AS "NASName_index",
            row_number() OVER "ShortName_window" AS "ShortName_index",
            foreign_nas."NASName",
            foreign_nas."ShortName",
            foreign_nas."Type",
            foreign_nas."Ports",
            foreign_nas."Secret",
            foreign_nas."Server",
            foreign_nas."Community",
            foreign_nas."Description"
           FROM foreign_nas
          WHERE ((foreign_nas."Id" IS NOT NULL) AND (foreign_nas."NASName" IS NOT NULL) AND (foreign_nas."ShortName" IS NOT NULL) AND (foreign_nas."Type" IS NOT NULL) AND (foreign_nas."Secret" IS NOT NULL))
          WINDOW "NASName_window" AS (PARTITION BY foreign_nas."NASName"), "ShortName_window" AS (PARTITION BY foreign_nas."ShortName")) indexed
  WHERE ((indexed."NASName_index" = 1) AND (indexed."ShortName_index" = 1))
  WITH NO DATA;


ALTER TABLE nas OWNER TO "hades-database";

SET default_with_oids = false;

--
-- Name: radacct; Type: TABLE; Schema: public; Owner: hades-database
--

CREATE TABLE radacct (
    "RadAcctId" bigint NOT NULL,
    "AcctSessionId" text NOT NULL,
    "AcctUniqueId" text NOT NULL,
    "UserName" text,
    "GroupName" text,
    "Realm" text,
    "NASIpAddress" inet NOT NULL,
    "NASPortId" text,
    "NASPortType" text,
    "AcctStartTime" timestamp with time zone,
    "AcctUpdateTime" timestamp with time zone,
    "AcctStopTime" timestamp with time zone,
    "AcctInterval" bigint,
    "AcctSessionTime" bigint,
    "AcctAuthentic" text,
    "ConnectInfo_start" text,
    "ConnectInfo_stop" text,
    "AcctInputOctets" bigint,
    "AcctOutputOctets" bigint,
    "CalledStationId" text,
    "CallingStationId" text,
    "AcctTerminateCause" text,
    "ServiceType" text,
    "FramedProtocol" text,
    "FramedIPAddress" inet
);


ALTER TABLE radacct OWNER TO "hades-database";

--
-- Name: radacct_RadAcctId_seq; Type: SEQUENCE; Schema: public; Owner: hades-database
--

CREATE SEQUENCE "radacct_RadAcctId_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "radacct_RadAcctId_seq" OWNER TO "hades-database";

--
-- Name: radacct_RadAcctId_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: hades-database
--

ALTER SEQUENCE "radacct_RadAcctId_seq" OWNED BY radacct."RadAcctId";


--
-- Name: radcheck; Type: MATERIALIZED VIEW; Schema: public; Owner: hades-database
--

CREATE MATERIALIZED VIEW radcheck AS
 SELECT row_number() OVER w AS "Priority",
    foreign_radcheck."UserName",
    foreign_radcheck."NASIpAddress",
    foreign_radcheck."NASPortId",
    foreign_radcheck."Attribute",
    foreign_radcheck."Op",
    foreign_radcheck."Value"
   FROM foreign_radcheck
  WHERE ((foreign_radcheck."UserName" IS NOT NULL) AND (foreign_radcheck."Attribute" IS NOT NULL) AND (foreign_radcheck."Op" IS NOT NULL) AND (foreign_radcheck."Value" IS NOT NULL))
  WINDOW w AS (PARTITION BY foreign_radcheck."UserName", foreign_radcheck."NASIpAddress", foreign_radcheck."NASPortId" ORDER BY foreign_radcheck."Priority")
  WITH NO DATA;


ALTER TABLE radcheck OWNER TO "hades-database";

--
-- Name: radgroupcheck; Type: MATERIALIZED VIEW; Schema: public; Owner: hades-database
--

CREATE MATERIALIZED VIEW radgroupcheck AS
 SELECT row_number() OVER w AS "Priority",
    foreign_radgroupcheck."GroupName",
    foreign_radgroupcheck."Attribute",
    foreign_radgroupcheck."Op",
    foreign_radgroupcheck."Value"
   FROM foreign_radgroupcheck
  WHERE ((foreign_radgroupcheck."GroupName" IS NOT NULL) AND (foreign_radgroupcheck."Attribute" IS NOT NULL) AND (foreign_radgroupcheck."Op" IS NOT NULL) AND (foreign_radgroupcheck."Value" IS NOT NULL))
  WINDOW w AS (PARTITION BY foreign_radgroupcheck."GroupName" ORDER BY foreign_radgroupcheck."Priority")
  WITH NO DATA;


ALTER TABLE radgroupcheck OWNER TO "hades-database";

--
-- Name: radgroupreply; Type: MATERIALIZED VIEW; Schema: public; Owner: hades-database
--

CREATE MATERIALIZED VIEW radgroupreply AS
 SELECT row_number() OVER w AS "Priority",
    foreign_radgroupreply."GroupName",
    foreign_radgroupreply."Attribute",
    foreign_radgroupreply."Op",
    foreign_radgroupreply."Value"
   FROM foreign_radgroupreply
  WHERE ((foreign_radgroupreply."GroupName" IS NOT NULL) AND (foreign_radgroupreply."Attribute" IS NOT NULL) AND (foreign_radgroupreply."Op" IS NOT NULL) AND (foreign_radgroupreply."Value" IS NOT NULL))
  WINDOW w AS (PARTITION BY foreign_radgroupreply."GroupName" ORDER BY foreign_radgroupreply."Priority")
  WITH NO DATA;


ALTER TABLE radgroupreply OWNER TO "hades-database";

--
-- Name: radpostauth; Type: TABLE; Schema: public; Owner: hades-database
--

CREATE TABLE radpostauth (
    "Id" bigint NOT NULL,
    "UserName" text NOT NULL,
    "NASIpAddress" inet NOT NULL,
    "NASPortId" text,
    "PacketType" text NOT NULL,
    "Groups" text[],
    "Reply" text[],
    "AuthDate" timestamp without time zone DEFAULT timezone('utc'::text, now()) NOT NULL
);


ALTER TABLE radpostauth OWNER TO "hades-database";

--
-- Name: radpostauth_Id_seq; Type: SEQUENCE; Schema: public; Owner: hades-database
--

CREATE SEQUENCE "radpostauth_Id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "radpostauth_Id_seq" OWNER TO "hades-database";

--
-- Name: radpostauth_Id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: hades-database
--

ALTER SEQUENCE "radpostauth_Id_seq" OWNED BY radpostauth."Id";


--
-- Name: radreply; Type: MATERIALIZED VIEW; Schema: public; Owner: hades-database
--

CREATE MATERIALIZED VIEW radreply AS
 SELECT row_number() OVER w AS "Priority",
    foreign_radreply."UserName",
    foreign_radreply."NASIpAddress",
    foreign_radreply."NASPortId",
    foreign_radreply."Attribute",
    foreign_radreply."Op",
    foreign_radreply."Value"
   FROM foreign_radreply
  WHERE ((foreign_radreply."UserName" IS NOT NULL) AND (foreign_radreply."Attribute" IS NOT NULL) AND (foreign_radreply."Op" IS NOT NULL) AND (foreign_radreply."Value" IS NOT NULL))
  WINDOW w AS (PARTITION BY foreign_radreply."UserName", foreign_radreply."NASIpAddress", foreign_radreply."NASPortId" ORDER BY foreign_radreply."Priority")
  WITH NO DATA;


ALTER TABLE radreply OWNER TO "hades-database";

--
-- Name: radusergroup; Type: MATERIALIZED VIEW; Schema: public; Owner: hades-database
--

CREATE MATERIALIZED VIEW radusergroup AS
 SELECT foreign_radusergroup."UserName",
    foreign_radusergroup."NASIpAddress",
    foreign_radusergroup."NASPortId",
    foreign_radusergroup."GroupName",
    row_number() OVER w AS "Priority"
   FROM foreign_radusergroup
  WHERE ((foreign_radusergroup."UserName" IS NOT NULL) AND (foreign_radusergroup."GroupName" IS NOT NULL))
  WINDOW w AS (PARTITION BY foreign_radusergroup."UserName", foreign_radusergroup."NASIpAddress", foreign_radusergroup."NASPortId" ORDER BY foreign_radusergroup."Priority")
  WITH NO DATA;


ALTER TABLE radusergroup OWNER TO "hades-database";

--
-- Name: radacct RadAcctId; Type: DEFAULT; Schema: public; Owner: hades-database
--

ALTER TABLE ONLY radacct ALTER COLUMN "RadAcctId" SET DEFAULT nextval('"radacct_RadAcctId_seq"'::regclass);


--
-- Name: radpostauth Id; Type: DEFAULT; Schema: public; Owner: hades-database
--

ALTER TABLE ONLY radpostauth ALTER COLUMN "Id" SET DEFAULT nextval('"radpostauth_Id_seq"'::regclass);


--
-- Data for Name: radacct; Type: TABLE DATA; Schema: public; Owner: hades-database
--

COPY radacct ("RadAcctId", "AcctSessionId", "AcctUniqueId", "UserName", "GroupName", "Realm", "NASIpAddress", "NASPortId", "NASPortType", "AcctStartTime", "AcctUpdateTime", "AcctStopTime", "AcctInterval", "AcctSessionTime", "AcctAuthentic", "ConnectInfo_start", "ConnectInfo_stop", "AcctInputOctets", "AcctOutputOctets", "CalledStationId", "CallingStationId", "AcctTerminateCause", "ServiceType", "FramedProtocol", "FramedIPAddress") FROM stdin;
\.


--
-- Name: radacct_RadAcctId_seq; Type: SEQUENCE SET; Schema: public; Owner: hades-database
--

SELECT pg_catalog.setval('"radacct_RadAcctId_seq"', 1, false);


--
-- Data for Name: radpostauth; Type: TABLE DATA; Schema: public; Owner: hades-database
--

COPY radpostauth ("Id", "UserName", "NASIpAddress", "NASPortId", "PacketType", "Groups", "Reply", "AuthDate") FROM stdin;
1	40:61:86:1c:df:fd	127.0.0.1	A1	Access-Accept	{test}	{{Egress-VLAN-Name,"\\"1KnownVLAN\\""},{Fall-Through,4},{Reply-Message,"\\"\\""}}	2017-05-15 17:23:49.484638
2	1e:a7:de:ad:be:ef	127.0.0.1	A1	Access-Accept	\N	\N	2017-05-15 17:23:50.205342
3	40:61:86:1c:df:fd	127.0.0.1	A1	Access-Reject	{test}	\N	2017-05-15 17:23:50.898973
4	40:61:86:1c:df:fd	127.0.0.1	A1	Access-Accept	{test}	{{Egress-VLAN-Name,"\\"1KnownVLAN\\""},{Fall-Through,4},{Reply-Message,"\\"\\""}}	2017-05-15 17:49:10.131443
5	1e:a7:de:ad:be:ef	127.0.0.1	A1	Access-Accept	\N	\N	2017-05-15 17:49:10.793724
6	40:61:86:1c:df:fd	127.0.0.1	A1	Access-Reject	{test}	\N	2017-05-15 17:49:11.496873
7	40:61:86:1c:df:fd	127.0.0.1	A1	Access-Accept	{test}	{{Egress-VLAN-Name,"\\"1KnownVLAN\\""},{Fall-Through,4},{Reply-Message,"\\"\\""}}	2017-05-15 17:53:34.767259
8	1e:a7:de:ad:be:ef	127.0.0.1	A1	Access-Accept	\N	\N	2017-05-15 17:53:35.484195
9	40:61:86:1c:df:fd	127.0.0.1	A1	Access-Reject	{test}	\N	2017-05-15 17:53:36.206538
10	40:61:86:1c:df:fd	127.0.0.1	A1	Access-Accept	{test}	{{Egress-VLAN-Name,"\\"1KnownVLAN\\""},{Fall-Through,4},{Reply-Message,"\\"\\""}}	2017-05-15 17:54:58.531641
11	1e:a7:de:ad:be:ef	127.0.0.1	A1	Access-Accept	\N	{{Egress-VLAN-Name,"\\"1UnknownVLAN\\""}}	2017-05-15 17:54:59.179366
12	40:61:86:1c:df:fd	127.0.0.1	A1	Access-Reject	{test}	\N	2017-05-15 17:54:59.936753
\.


--
-- Name: radpostauth_Id_seq; Type: SEQUENCE SET; Schema: public; Owner: hades-database
--

SELECT pg_catalog.setval('"radpostauth_Id_seq"', 12, true);


--
-- Name: radacct radacct_AcctUniqueId_key; Type: CONSTRAINT; Schema: public; Owner: hades-database
--

ALTER TABLE ONLY radacct
    ADD CONSTRAINT "radacct_AcctUniqueId_key" UNIQUE ("AcctUniqueId");


--
-- Name: radacct radacct_pkey; Type: CONSTRAINT; Schema: public; Owner: hades-database
--

ALTER TABLE ONLY radacct
    ADD CONSTRAINT radacct_pkey PRIMARY KEY ("RadAcctId");


--
-- Name: radpostauth radpostauth_pkey; Type: CONSTRAINT; Schema: public; Owner: hades-database
--

ALTER TABLE ONLY radpostauth
    ADD CONSTRAINT radpostauth_pkey PRIMARY KEY ("Id");


--
-- Name: alternative_dns_IpAddress_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE UNIQUE INDEX "alternative_dns_IpAddress_idx" ON alternative_dns USING btree ("IpAddress");


--
-- Name: dhcphost_IpAddress_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE UNIQUE INDEX "dhcphost_IpAddress_idx" ON dhcphost USING btree ("IpAddress");


--
-- Name: dhcphost_Mac_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE UNIQUE INDEX "dhcphost_Mac_idx" ON dhcphost USING btree ("Mac");


--
-- Name: nas_NASName_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE UNIQUE INDEX "nas_NASName_idx" ON nas USING btree ("NASName");


--
-- Name: radacct_active_session_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE INDEX radacct_active_session_idx ON radacct USING btree ("AcctUniqueId") WHERE ("AcctStopTime" IS NULL);


--
-- Name: radacct_bulk_close; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE INDEX radacct_bulk_close ON radacct USING btree ("NASIpAddress", "AcctStartTime") WHERE ("AcctStopTime" IS NULL);


--
-- Name: radacct_start_user_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE INDEX radacct_start_user_idx ON radacct USING btree ("AcctStartTime", "UserName");


--
-- Name: radcheck_user_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE UNIQUE INDEX radcheck_user_idx ON radcheck USING btree ("UserName", "NASIpAddress", "NASPortId", "Priority");


--
-- Name: radgroupcheck_group_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE UNIQUE INDEX radgroupcheck_group_idx ON radgroupcheck USING btree ("GroupName", "Priority");


--
-- Name: radgroupreply_group_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE UNIQUE INDEX radgroupreply_group_idx ON radgroupreply USING btree ("GroupName", "Priority");


--
-- Name: radpostauth_AuthDate_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE INDEX "radpostauth_AuthDate_idx" ON radpostauth USING brin ("AuthDate") WITH (pages_per_range='16');


--
-- Name: radpostauth_UserName_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE INDEX "radpostauth_UserName_idx" ON radpostauth USING btree ("UserName");


--
-- Name: radpostauth_port_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE INDEX radpostauth_port_idx ON radpostauth USING btree ("NASIpAddress", "NASPortId");


--
-- Name: radreply_user_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE UNIQUE INDEX radreply_user_idx ON radreply USING btree ("UserName", "NASIpAddress", "NASPortId", "Priority");


--
-- Name: radusergroup_membership_idx; Type: INDEX; Schema: public; Owner: hades-database
--

CREATE UNIQUE INDEX radusergroup_membership_idx ON radusergroup USING btree ("UserName", "NASIpAddress", "NASPortId", "GroupName", "Priority");


--
-- Name: alternative_dns; Type: MATERIALIZED VIEW DATA; Schema: public; Owner: hades-database
--

REFRESH MATERIALIZED VIEW alternative_dns;


--
-- Name: dhcphost; Type: MATERIALIZED VIEW DATA; Schema: public; Owner: hades-database
--

REFRESH MATERIALIZED VIEW dhcphost;


--
-- Name: nas; Type: MATERIALIZED VIEW DATA; Schema: public; Owner: hades-database
--

REFRESH MATERIALIZED VIEW nas;


--
-- Name: radcheck; Type: MATERIALIZED VIEW DATA; Schema: public; Owner: hades-database
--

REFRESH MATERIALIZED VIEW radcheck;


--
-- Name: radgroupcheck; Type: MATERIALIZED VIEW DATA; Schema: public; Owner: hades-database
--

REFRESH MATERIALIZED VIEW radgroupcheck;


--
-- Name: radgroupreply; Type: MATERIALIZED VIEW DATA; Schema: public; Owner: hades-database
--

REFRESH MATERIALIZED VIEW radgroupreply;


--
-- Name: radreply; Type: MATERIALIZED VIEW DATA; Schema: public; Owner: hades-database
--

REFRESH MATERIALIZED VIEW radreply;


--
-- Name: radusergroup; Type: MATERIALIZED VIEW DATA; Schema: public; Owner: hades-database
--

REFRESH MATERIALIZED VIEW radusergroup;


--
-- Name: radacct; Type: ACL; Schema: public; Owner: hades-database
--

GRANT SELECT ON TABLE radacct TO "hades-agent";
GRANT SELECT ON TABLE radacct TO "hades-portal";
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE radacct TO "hades-radius";


--
-- Name: radacct_RadAcctId_seq; Type: ACL; Schema: public; Owner: hades-database
--

GRANT SELECT,USAGE ON SEQUENCE "radacct_RadAcctId_seq" TO "hades-radius";


--
-- Name: radcheck; Type: ACL; Schema: public; Owner: hades-database
--

GRANT SELECT ON TABLE radcheck TO "hades-radius";


--
-- Name: radgroupcheck; Type: ACL; Schema: public; Owner: hades-database
--

GRANT SELECT ON TABLE radgroupcheck TO "hades-radius";


--
-- Name: radgroupreply; Type: ACL; Schema: public; Owner: hades-database
--

GRANT SELECT ON TABLE radgroupreply TO "hades-radius";


--
-- Name: radpostauth; Type: ACL; Schema: public; Owner: hades-database
--

GRANT SELECT ON TABLE radpostauth TO "hades-agent";
GRANT SELECT ON TABLE radpostauth TO "hades-portal";
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE radpostauth TO "hades-radius";


--
-- Name: radpostauth_Id_seq; Type: ACL; Schema: public; Owner: hades-database
--

GRANT SELECT,USAGE ON SEQUENCE "radpostauth_Id_seq" TO "hades-radius";


--
-- Name: radreply; Type: ACL; Schema: public; Owner: hades-database
--

GRANT SELECT ON TABLE radreply TO "hades-portal";
GRANT SELECT ON TABLE radreply TO "hades-radius";


--
-- Name: radusergroup; Type: ACL; Schema: public; Owner: hades-database
--

GRANT SELECT ON TABLE radusergroup TO "hades-portal";
GRANT SELECT ON TABLE radusergroup TO "hades-radius";


--
-- PostgreSQL database dump complete
--

